
---------------------------------------------------------------
-- Message Box / Alert Box
---------------------------------------------------------------

GTK.Core.GUI:addImage({ name="log2-guiitems-alert", path="assets/textures/gui/gui_items.tga", origin={2032, 0}, size={436, 300}, margin={80, 80, 80, 81} });

alertForm = {
	name = "gtk_alert",
	type = "GWindow",
	position = {10, 10},
	size = {436, 300},
	bgColor = {0, 0, 0, 0},
	bgImage = "log2-guiitems-alert",
	bgDrawMode = GTK.Constants.ImageDrawMode.Stretched,
	gravity = GTK.Constants.Gravity.Middle,
	draggable = true,
	dimScreen = true,
	children = {
		{
			type = "GLabel",
			name = "title",
			position = {54, 32},
			size = {340, 20},
			text = "",
			font = GTK.Constants.Fonts.Medium
		},
		{
			type = "GLabel",
			name = "message",
			position = {48, 82},
			size = {340, 60},
			text = "",
			font = GTK.Constants.Fonts.Small
		},
		{
			type = "GButton",
			name = "cancelButton",
			position = {48, 222},
			size = {128, 24},
			bgColor = {0, 0, 0, 128},
			padding = {4, 4, 4, 4},
			borders = {2, 2, 2, 2},
			text = "Cancel",
			font = GTK.Constants.Fonts.Small
		},
		{
			type = "GButton",
			name = "okButton",
			position = {268, 222},
			size = {128, 24},
			bgColor = {0, 0, 0, 128},
			padding = {4, 4, 4, 4},
			borders = {2, 2, 2, 2},
			text = "OK",
			font = GTK.Constants.Fonts.Small
		}
	}
}

function showMessageBox(title, message, onDismiss, okText, cancelText)
	if ( GTK.Core.GUI:getWindow(alertForm.name) ) then
		Console.warn("[GTK] MessageBox is already showing. Cannot show another.");
		return
	end

	local window = GTK.Core.GUI:createWindow(alertForm);
	
	if ( window == nil ) then
		return
	end

	local titleLabel = window:findChild("title");
	local messageLabel = window:findChild("message");
	local okButton = window:findChild("okButton");
	local cancelButton = window:findChild("cancelButton");

	if ( titleLabel ~= nil ) then
		titleLabel.data.text = title;
	end

	if ( messageLabel ~= nil ) then
		messageLabel.data.text = message;
	end
	
	local onButtonPress = function(sender, mouseState)
		GTK.Core.GUI:destroyWindow(alertForm.name);
		
		if ( onDismiss ~= nil ) then
			onDismiss(sender.data.text);
		end
	end
	
	if ( cancelButton ~= nil ) then
		if ( cancelText == nil ) then
			cancelButton:setVisible(false);
		else 
			cancelButton.data.text = cancelText;
			cancelButton:setHook("onPressed", onButtonPress);
		end
	end
	
	if ( okButton ~= nil ) then
		if ( okText == nil ) then okText = "Okay"; end
		
		okButton.data.text = okText;
		okButton:setHook("onPressed", onButtonPress);
	end	
end

function dismissMessageBox()
	GTK.Core.GUI:destroyWindow(alertForm.name);
end

---------------------------------------------------------------
-- Show an Info Message in the middle of the screen
---------------------------------------------------------------

GTK.Core.GUI:addImage({ name="gtk-info-message-box", path="mod_assets/grimtk/textures/info_message_box.tga", origin={0, 0}, size={512, 88} });

infoMessageForm = {
	name = "gtk_info_message",
	type = "GWindow",
	position = {0, 0},
	size = {512, 88},
	bgColor = {0, 0, 0, 0},
	bgImage = "gtk-info-message-box",
	bgDrawMode = GTK.Constants.ImageDrawMode.Stretched,
	gravity = GTK.Constants.Gravity.Middle,
	draggable = false,
	dimScreen = false,	
	children = {
		{
			type = "GLabel",
			name = "message",
			position = {36, 11},
			size = {440, 66},
			text = "Example",
			textColor = {255, 255, 255, 255},
			font = GTK.Constants.Fonts.Medium
		}
	}
}

function showInfoMessage(text, duration)
	if ( duration == nil ) then duration = 3.0; end
	local window = GTK.Core.GUI:getWindow(infoMessageForm.name);

	if ( window == nil ) then
		window = GTK.Core.GUI:createWindow(infoMessageForm);
	end

	if ( window == nil ) then
		Console.warn("[GTK] InfoMessage Failed: " .. text);
		return;
	end
	
	local messageLabel = window:findChild("message");

	if ( messageLabel ~= nil ) then
		messageLabel.data.text = text;
	end
	
	window:setOpacity(1.0);
	window:setVisible(true);

	local actionSequence = GTK.Widgets.GSequenceAction.create({
		GTK.Widgets.GWaitAction.create(duration),
		GTK.Widgets.GFadeToAction.create(0.0, 1.0)
	});
	
	window:stopAllActions();
	window:runAction(actionSequence);
	
end

function hideInfoMessage()
	local window = GTK.Core.GUI:getWindow(infoMessageForm.name);
	
	if ( window ) then
		window:setVisible(false);
	end
end