form = nil;
formName = "gtk_notebook";

state = {
	isOpen = false,
	window = nil,
	bookChampionOrd = 0,
	bookSlot = 0,
	currentPage = 0,
};

introPageText = "Usage Instructions...\n\n [Left Arrow]: Previous Page";

function gtkDidLoad()
	GTK.Core.GUI:addImage({ name="gtk-nb-book", path="mod_assets/gtk_notebook/textures/book.tga", origin={0, 0}, size={880, 482} });
	
	form = {
		name = formName,
		type = "GWindow",
		gravity = GTK.Constants.Gravity.Middle,
		offset = {0, 0},
		size = {880, 482},
		bgColor = {0, 0, 0, 0},
		bgImage = "gtk-nb-book",
		bgDrawMode = GTK.Constants.ImageDrawMode.Stretched,
		draggable = true,
		children = { 
			{
				name = "pageCountLabel",
				type = "GLabel",
				position = {150, 404},
				size = {170, 18},
				text = ""
			},
			{
				name = "leftPageContent",
				type = "GTextEdit",
				position = {52, 16},
				size = {372, 372},
				multiLine = true
			},
			{
				name = "rightPageContent",
				type = "GTextEdit",
				position = {445, 16},
				size = {372, 372},
				multiLine = true
			},
			{
				name = "closeButton",
				type = "GButton",
				position = {824, 26},
				size = {24, 24},
				onPressed = function(sender, mouseState)
					close();
				end
			},
			{
				name = "closeButton",
				type = "GButton",
				position = {824, 26},
				size = {24, 24},
				onPressed = function(sender, mouseState)
					close();
				end			
			}
		}
	}
end

----
-- "Public" interface for notebooks
----

function isOpen(self)
	return self.state.isOpen;
end

function open(self, championOrdinal, itemId)
	if ( state.isOpen == true ) then
		closeNotebook();
	end
	
	local champion = party.party:getChampionByOrdinal(championOrdinal);
	local itemSlot = self:getItemSlot(champion, itemId);
	
	if ( itemSlot > 0 ) then
		state.bookChampionOrd = championOrdinal;
		state.bookSlot = itemSlot;
		state.isOpen = true;
		state.currentPage = 0;
		state.window = GTK.Core.GUI:createWindow(form);
		
		self:updateView();
	end
end

function close(self)
	if ( state.isOpen == true ) then 
		state.bookChampionOrd = 0;
		state.bookSlot = 0;
		state.currentPage = 0;
		state.isOpen = false;
		
		GTK.Core.GUI:removeWindow(state.window);
		state.window = nil;
	end
end


----
-- Internal Methods
----

function getItemSlot(self, champion, itemId)
	for i=1,32 do 
		local item = champion:getItem(i);
		
		if ( (item ~= nil) and (item.go.id == itemId) ) then
			return i;
		end
	end
	
	return 0;
end

function getOpenBookEntity(self)
	local state = self.state;

	if ( state.isOpen == false or state.bookChampionOrd < 1 or state.bookChampionOrd > 4 or state.bookSlot < 1 or state.bookSlot > 32 ) then
		return nil;
	end

	local champion = party.party:getChampionByOrdinal(state.bookChampionOrd);
	
	if ( champion == nil ) then
		return nil;
	end
	
	local item = champion:getItem(state.bookSlot);
	
	if ( item == nil ) then
		return nil;
	end
	
	return item.go;
end

function getOpenBookPageCount(self)
	local entity = self:getOpenBookEntity();
	
	if ( entity == nil or entity.containeritem == nil ) then
		return 0;
	end
	
	for i=1,100 do
		local item = entity.containeritem:getItem(i);
		
		if ( item == nil ) then
			return i-1;
		end
	end
	
	return 0;
end

function getOpenBookPageText(self, page)
	local entity = self:getOpenBookEntity();
	
	if ( entity == nil or entity.containeritem == nil ) then
		return "";
	end

	if ( page < 1 ) then
		return introPageText;
	end

	local pageItem = entity.containeritem:getItem(page);
	
	if ( pageItem == nil or pageItem.go.scrollitem ) then
		return "";
	end
	
	return pageItem.scrollitem:getScrollText();
end

function updateView(self)
	local state = self.state;
	
	if ( state.isOpen == false or state.window == nil ) then	
		return false;
	end
	
	local pageCountLabel = state.window:findChild("pageCountLabel");
	local leftPageTextEdit = state.window:findChild("leftPageContent");
	local rightPageTextEdit = state.window:findChild("rightPageContent");
	
	local pageCount = self:getOpenBookPageCount();	
	local leftPageText = self:getOpenBookPageText(state.currentPage);
	local rightPageText = self:getOpenBookPageText(state.currentPage+1);
	
	if ( pageCountLabel ) then 
		if ( pageCount == 0 ) then 
			pageCountLabel.data.text = "Empty Book";
		else 
			pageCountLabel.data.text = state.currentPage .. " of " .. pageCount; 
		end
	end
	
	if ( leftPageTextEdit ) then 
		leftPageTextEdit.data.text = leftPageText;
	end

	if ( rightPageTextEdit ) then 
		rightPageTextEdit.data.text = rightPageText;
	end
	
	return true;
end



